# Changelog

## [1.0.0] - 2025-01-03

Initial public release.

### Features
- Multi-provider support (Anthropic, OpenAI, Google, xAI, Ollama)
- Extended thinking for Claude models
- Event-driven architecture with JSONL storage
- DuckDB analytics database
- Auto-generated Jupyter notebooks
- Real-time monitoring
- Conversation branching
- 150+ metrics per turn
